@@ -16,20 +16,29 @@ logger = logging.getLogger()
 
 
 @click.command()
+@click.option(
+    "--all",
+    "all_entries",
+    is_flag=True,
+    help="Use all of the changelog entries.",
+)
 @click_log.simple_verbosity_option(logger)
-def github_release() -> None:
+def github_release(all_entries: bool) -> None:
     """
-    Update GitHub releases from the changelog.
+    Create or update GitHub releases from the changelog.
+
+    Only the most recent changelog entry is used, unless --all is provided.
+
     """
     scriv = Scriv()
     changelog = scriv.changelog()
     changelog.read()
 
-    tags = set(run_simple_command("git tags").split())
     repo = get_github_repo()
     if repo is None:
         sys.exit("Couldn't determine GitHub repo.")
 
+    tags = set(run_simple_command("git tag").split())
     releases = get_releases(repo)
 
     for title, sections in changelog.entries().items():
@@ -37,6 +46,7 @@ def github_release() -> None:
             continue
         version = extract_version(title)
         if version is None:
+            logger.warning(f"Entry {title!r} has no version, skipping.")
             continue
 
         if version in tags:
@@ -59,3 +69,6 @@ def github_release() -> None:
             logger.warning(
                 f"Version {version} has no tag. No release will be made."
             )
+
+        if not all_entries:
+            break
